Module cmd

Module cmd 

Command implementations for CLI tools.

Each module contains the full implementation for a command, which can be invoked by thin wrapper binaries.

Modules

check
Shared implementation for bean-check and rledger check commands.
completions
Shell completion generation.
doctor
bean-doctor - Debugging tool for beancount files.
extract_cmd
rledger extract - Extract transactions from bank files.
format
Shared implementation for bean-format and rledger format commands.
price_cmd
Price fetching command for rustledger.
query
rledger query - Query beancount files with BQL.
report_cmd
rledger report - Generate financial reports from beancount files.